pub enum IgnoreType {
Default,
Hidden,
GitIgnore,
GitGlobal,
GitExclude,
Ignore,
}Expand description
Define the ignore types for directory traversing.
Variants
Default
use git-ignore, .gitglobal, .gitexclude, and .ignore.
Hidden
ignore hidden files and directories.
GitIgnore
ignore files and directories that are listed in .gitignore.
GitGlobal
ignore files and directories that are listed in .gitglobal.
GitExclude
ignore files and directories that are listed in .gitexclude.
Ignore
ignore files and directories that are listed in .ignore.